@@ -460,7 +460,8 @@ class VolumetricSampler(Sampler):
             rays_d=rays_d,
             scene_aabb=self.scene_aabb,
             grid=self.occupancy_grid,
-            sigma_fn=self.get_sigma_fn(rays_o, rays_d),
+            # this is a workaround - using density causes crash and damage quality. should be fixed
+            sigma_fn=None,  # self.get_sigma_fn(rays_o, rays_d),
             render_step_size=render_step_size,
             near_plane=near_plane,
             far_plane=far_plane,
